/** @typedef {import("../src/display/api").PDFDocumentProxy} PDFDocumentProxy */
/** @typedef {import("./event_utils").EventBus} EventBus */
/** @typedef {import("./interfaces").IL10n} IL10n */
/** @typedef {import("./interfaces").IPDFLinkService} IPDFLinkService */
/** @typedef {import("./pdf_rendering_queue").PDFRenderingQueue} PDFRenderingQueue */
import { watchScroll } from "./ui_utils";
import { PDFThumbnailView } from "./pdf_thumbnail_view";
import { EventBus } from "pdfjs-dist/web/pdf_viewer.mjs";
import { PDFDocumentProxy } from "pdfjs-dist";
import { StoreApi } from "zustand/vanilla";
import type { PDFSlickState } from "../types";
import { PDFViewerOptions } from "pdfjs-dist/types/web/pdf_viewer";
import type { PDFRenderingQueue } from "./pdf_rendering_queue";
/**
 * @typedef {Object} PDFThumbnailViewerOptions
 * @property {HTMLDivElement} container - The container for the thumbnail
 *   elements.
 * @property {EventBus} eventBus - The application event bus.
 * @property {IPDFLinkService} linkService - The navigation/linking service.
 * @property {PDFRenderingQueue} renderingQueue - The rendering queue object.
 * @property {Object} [pageColors] - Overwrites background and foreground colors
 *   with user defined ones in order to improve readability in high contrast
 *   mode.
 * @property {AbortSignal} [abortSignal] - The AbortSignal for the window
 *   events.
 * @property {boolean} [enableHWA] - Enables hardware acceleration for
 *   rendering. The default value is `false`.
 */
type PDFThumbnailViewerOptions = {
    container: HTMLDivElement;
    eventBus: EventBus;
    linkService: NonNullable<PDFViewerOptions['linkService']>;
    renderingQueue: PDFRenderingQueue;
    pageColors: {
        background: any;
        foreground: any;
    } | null;
    abortSignal?: AbortSignal;
    enableHWA: boolean | undefined;
    store: StoreApi<PDFSlickState>;
    thumbnailWidth: number;
};
/**
 * Viewer control to display thumbnails for pages in a PDF document.
 */
declare class PDFThumbnailViewer {
    #private;
    container: HTMLElement;
    eventBus: EventBus;
    linkService: PDFThumbnailViewerOptions['linkService'];
    renderingQueue: PDFRenderingQueue;
    pageColors: {
        background: any;
        foreground: any;
    } | null;
    enableHWA: boolean;
    scroll: ReturnType<typeof watchScroll>;
    pdfDocument: PDFDocumentProxy | null;
    _thumbnails: PDFThumbnailView[];
    _currentPageNumber: number;
    _pagesRotation?: number | null;
    _pageLabels: string[] | null;
    store: StoreApi<PDFSlickState>;
    thumbnailWidth: number;
    /**
     * @param {PDFThumbnailViewerOptions} options
     */
    constructor({ container, eventBus, linkService, renderingQueue, pageColors, abortSignal, enableHWA, store, thumbnailWidth, }: PDFThumbnailViewerOptions);
    getThumbnail(index: number): PDFThumbnailView;
    scrollThumbnailIntoView(pageNumber: number): void;
    get pagesRotation(): number | null | undefined;
    set pagesRotation(rotation: number | null | undefined);
    cleanup(): void;
    /**
     * @param {PDFDocumentProxy} pdfDocument
     */
    setDocument(pdfDocument: PDFDocumentProxy): void;
    /**
     * @param {Array|null} labels
     */
    setPageLabels(labels: string[] | null): void;
    forceRendering(): boolean;
}
export { PDFThumbnailViewer };
//# sourceMappingURL=pdf_thumbnail_viewer.d.ts.map